@@ -1,4 +1,4 @@
-(* $Id: netcgi.ml,v 1.14 2005/02/02 21:19:47 gremlin43820 Exp $
+(* $Id: netcgi.ml,v 1.15 2005/07/25 22:36:40 stolpmann Exp $
  * ----------------------------------------------------------------------
  *
  *)
@@ -6,49 +6,13 @@
 open Netcgi_env ;;
 open Netcgi_types ;;
 open Netchannels ;;
+open Nethttp ;;
 
+let status_line (s:http_status) =
+  let code = int_of_http_status s in
+  let text = string_of_http_status s in
+  string_of_int code ^ " " ^ text
 
-let status_line (s:status) =
-  match s with
-      `Ok -> "200 OK"
-    | `Created -> "201 Created"
-    | `Accepted -> "202 Accepted"
-    | `Non_authoritative -> "203 Non-Authoritative Information"
-    | `No_content -> "204 No content"
-    | `Reset_content -> "205 Reset Content"
-    | `Partial_content -> "206 Partial Content"
-    | `Multiple_choices -> "300 Multiple Choices"
-    | `Moved_permanently -> "301 Moved Permanently"
-    | `Found -> "302 Found"
-    | `See_other -> "303 See Other"
-    | `Not_modified -> "304 Not Modified"
-    | `Use_proxy -> "305 Use Proxy"
-    | `Temporary_redirect -> "307 Temporary Redirect"
-    | `Bad_request -> "400 Bad Request"
-    | `Unauthorized -> "401 Unauthorized"
-    | `Payment_required -> "402 Payment Required"
-    | `Forbidden -> "403 Forbidden"
-    | `Not_found -> "404 Not Found"
-    | `Method_not_allowed -> "405 Method Not Allowed"
-    | `Not_acceptable -> "406 Not Acceptable"
-    | `Proxy_auth_required -> "407 Proxy Authentication Required"
-    | `Request_timeout -> "408 Request Timeout"
-    | `Conflict -> "409 Conflict"
-    | `Gone -> "410 Gone"
-    | `Length_required -> "411 Length Required"
-    | `Precondition_failed -> "412 Precondition Failed"
-    | `Request_entity_too_large -> "413 Request Entity Too Large"
-    | `Request_uri_too_long -> "414 Request-URI Too Long"
-    | `Unsupported_media_type -> "415 Unsupported Media Type"
-    | `Requested_range_not_satisfiable -> "416 Requested Range Not Satisfiable"
-    | `Expectation_failed -> "417 Expectation Failed"
-    | `Internal_server_error -> "500 Internal Server Error"
-    | `Not_implemented -> "501 Not Implemented"
-    | `Bad_gateway -> "502 Bad Gateway"
-    | `Service_unavailable -> "503 Service Unavailable"
-    | `Gateway_timeout -> "504 Gateway Timeout"
-    | `Http_version_not_supported -> "505 HTTP Version Not Supported"
-;;
 
 class simple_argument ?(ro=false) name value : cgi_argument =
 object(self)
@@ -472,32 +436,7 @@ object (self)
       environ # set_output_header_field "Content-script-type" script_type;
     if style_type <> "" then
       environ # set_output_header_field "Content-style-type" style_type;
-    let cookie_fields =
-      List.map
-	(fun c ->
-	   let enc_name  = Netencoding.Url.encode ~plus:false c.cookie_name in
-	   let enc_value = Netencoding.Url.encode ~plus:false c.cookie_value in
-	   enc_name ^ "=" ^ enc_value ^ 
-	   ( match c.cookie_expires with
-		 None -> ""
-	       | Some t -> 
-		   ";EXPIRES=" ^ Netdate.mk_usenet_date t
-	   ) ^ 
-	   (match c.cookie_domain with
-		None -> ""
-	      | Some d ->
-		  ";DOMAIN=" ^ d
-	   ) ^
-	   (match c.cookie_path with
-		None -> ""
-	      | Some p ->
-		  ";PATH=" ^ p 
-	   ) ^
-	   if c.cookie_secure then ";SECURE" else ""
-	)
-	set_cookie
-    in
-    environ # set_multiple_output_header_field "Set-cookie" cookie_fields;
+    Nethttp.Header.set_set_cookie environ#output_header set_cookie;
     List.iter
       (fun (n,vlist) ->
 	 environ # set_multiple_output_header_field n vlist
@@ -750,6 +689,15 @@ let tempfile_transactional_optype =
  * History:
  * 
  * $Log: netcgi.ml,v $
+ * Revision 1.15  2005/07/25 22:36:40  stolpmann
+ * Merge of nethttpd.
+ * Adding the "overview" section to Nethttpd_types.
+ * Cosmetic fixes.
+ * Release updates.
+ *
+ * Revision 1.14.2.1  2005/04/30 16:31:16  stolpmann
+ * Integration of the new Nethttpd component into Ocamlnet.
+ *
  * Revision 1.14  2005/02/02 21:19:47  gremlin43820
  * do the same for content type, and content disposition
  *
