@@ -1,9 +1,10 @@
-(* $Id: netcgi_env.ml,v 1.13 2004/11/24 18:01:13 gremlin43820 Exp $
+(* $Id: netcgi_env.ml,v 1.14 2005/07/25 22:36:40 stolpmann Exp $
  * ----------------------------------------------------------------------
  *
  *)
 
-open Netchannels ;;
+open Netchannels
+open Nethttp
 
 type input_mode = 
     [ `Standard (* | `Direct *) ] ;;
@@ -22,15 +23,10 @@ type output_state =
       `Sending_part_body   | `Sent_part_body |
       `End
     ] ;;
-type protocol_version = 
-    int * int ;;          (* (major,minor) number *)
-type protocol_attribute =
-  [ `Secure_https
-  ] ;;
-type protocol =
-  [ `Http of (protocol_version * protocol_attribute list)
-  | `Other
-  ] ;;
+type protocol_version = Nethttp.protocol_version
+type protocol_attribute = Nethttp.protocol_attribute
+type protocol = Nethttp.protocol
+
 type workaround =
   [ `Work_around_MSIE_Content_type_bug
   | `Work_around_backslash_bug
@@ -66,7 +62,9 @@ object
   method cgi_remote_ident       : string
 
   method cgi_property           : ?default:string -> string -> string
+  method cgi_properties         : (string * string) list
   method cgi_https              : bool
+  method cgi_request_uri        : string
 
   method protocol : protocol
 
@@ -94,6 +92,7 @@ object
   method output_header_field : ?default:string -> string -> string
   method multiple_output_header_field : string -> string list
   method output_header_fields : (string * string) list
+  method set_status : http_status -> unit
 
   method set_output_header_field : string -> string -> unit
   method set_multiple_output_header_field : string -> string list -> unit
@@ -103,6 +102,8 @@ object
   method output_state : output_state
   method set_output_state : output_state -> unit
 
+  method log_error : string -> unit
+
 end ;;
 
 exception Std_environment_not_found ;;
@@ -134,34 +135,6 @@ let default_config =
 
 let minus_re = Pcre.regexp "-";;
 
-exception No_equation of string
-
-let split_name_is_value s =
-  (* TODO: Move to aux module *)
-  (* Recognizes a string "name=value" and returns the pair (name,value).
-   * If the string has the wrong format, the function will raise
-   * No_equation, and the argument of the exception is the unparseable
-   * string.
-   *)
-  try
-    let p = String.index s '=' in
-    (String.sub s 0 p, String.sub s (p+1) (String.length s - p - 1))
-  with
-      Not_found ->
-	raise(No_equation s)
-;;
-
-
-let spaces_at_beginning_re = Pcre.regexp "^\\s+";;
-let spaces_at_end_re = Pcre.regexp "\\s+$";;
-
-let strip_spaces s =
-  (* Remove leading and trailing spaces: *)
-  Pcre.qreplace ~rex:spaces_at_end_re
-    (Pcre.qreplace ~rex:spaces_at_beginning_re s)
-;;
-
-let split_cookies_re = Pcre.regexp "[ \t\r\n]*;[ \t\r\n]*" ;;
 
 class base_environment ?(config = default_config) () =
 object (self)
@@ -224,6 +197,8 @@ object (self)
 	None   -> List.assoc name property
       | Some d -> try List.assoc name property with Not_found -> d
 
+  method cgi_properties = property
+
   method cgi_https = 
     match String.lowercase(self # cgi_property ~default:"" "HTTPS") with
 	"on"  -> true
@@ -231,6 +206,10 @@ object (self)
       | ""    -> false
       | _     -> failwith "Cannot interpret HTTPS property"
 
+  method cgi_request_uri =
+    self # cgi_property ~default:"" "REQUEST_URI"
+      (* Apache has this usually *)
+
   method protocol : protocol =
     try
       let groups = Pcre.extract ~rex:(Pcre.regexp "^([^/]+)/(\\d+)\\.(\\d+)$")
@@ -264,33 +243,7 @@ object (self)
     self # input_header_field ~default:"" "USER-AGENT"
 
   method cookies =
-    let cstrings = self # multiple_input_header_field "COOKIE" in
-    (* Remove leading and trailing spaces: *)
-    let cstrings' = List.map strip_spaces cstrings in
-    let partss = List.map
-		   (fun cstring ->
-		      Pcre.split
-		        ~max:(-1)
-		        ~rex:split_cookies_re
-			cstring
-		   )
-		   cstrings' in
-    let parts = List.flatten partss in
-			
-    List.map
-      (fun part ->
-	 let n,v = 
-	   try split_name_is_value part
-	   with No_equation _ -> (part, "")
-	        (* Because it is reported that MSIE returns just "n" instead
-		 * of "n=" when the value v is empty
-		 *)
-	 in
-	 let n_dec = Netencoding.Url.decode n in
-	 let v_dec = Netencoding.Url.decode v in
-	 (n_dec, v_dec)
-      )
-      parts
+    Nethttp.Header.get_cookie self#input_header
       
   method input_ch = in_ch
 
@@ -334,6 +287,9 @@ object (self)
   method set_output_header_fields h =
     out_header # set_fields h
 
+  method set_status st =
+    out_header # update_field "Status" (string_of_int (int_of_http_status st))
+
   method send_output_header () =
     if out_state <> `Start then
       failwith "send_output_header";
@@ -350,6 +306,10 @@ object (self)
     if s = `End then
       ( try out_ch # close_out() with Closed_channel -> () )
 
+  method log_error s =
+    prerr_endline s
+      (* This usually works for command-line and CGI *)
+
 end ;;
 
 
@@ -453,7 +413,21 @@ let isatty() =
 	assert false
 ;;
 
+exception No_equation of string
 
+let split_name_is_value s =
+  (* Recognizes a string "name=value" and returns the pair (name,value).
+   * If the string has the wrong format, the function will raise
+   * No_equation, and the argument of the exception is the unparseable
+   * string.
+   *)
+  try
+    let p = String.index s '=' in
+    (String.sub s 0 p, String.sub s (p+1) (String.length s - p - 1))
+  with
+	Not_found ->
+          raise(No_equation s)
+	  
 class test_environment ?config () =
 object (self)
   inherit base_environment ?config ()
@@ -726,6 +700,7 @@ object (self)
   inherit base_environment ?config ()
 
   val mutable setup_phase = true
+  val mutable error_log = prerr_endline
 
 
   method set_input_ch ch = 
@@ -751,6 +726,8 @@ object (self)
   method set_input_header_fields h =
     in_header # set_fields h
 
+  method set_error_log f =
+    error_log <- f
 
   method set_cgi
            ?gateway_interface
@@ -814,6 +791,8 @@ object (self)
     setup_phase <- false;
     in_header <- new Netmime.basic_mime_header ~ro:true in_header#fields
 
+  method log_error s =
+    error_log s
 end ;;
 
     
@@ -822,6 +801,15 @@ end ;;
  * History:
  * 
  * $Log: netcgi_env.ml,v $
+ * Revision 1.14  2005/07/25 22:36:40  stolpmann
+ * Merge of nethttpd.
+ * Adding the "overview" section to Nethttpd_types.
+ * Cosmetic fixes.
+ * Release updates.
+ *
+ * Revision 1.13.2.1  2005/04/30 16:31:16  stolpmann
+ * Integration of the new Nethttpd component into Ocamlnet.
+ *
  * Revision 1.13  2004/11/24 18:01:13  gremlin43820
  * commiting fastcgi compatibility patch from Kristof Pap which allows us to talk to a wider variety of fastcgi enabled web servers, and more closely follows the standard.
  *
