@@ -1,4 +1,4 @@
-(* $Id: netcgi_env.mli,v 1.8 2004/07/24 18:30:49 stolpmann Exp $
+(* $Id: netcgi_env.mli,v 1.9 2005/07/25 22:36:40 stolpmann Exp $
  * ----------------------------------------------------------------------
  *
  *)
@@ -98,19 +98,14 @@ type output_state =
      *   up to a check point
      *)
 
-type protocol_version = 
-    int * int           (* (major,minor) number *)
-      (** A pair of a major and minor version number *)
+type protocol_version = Nethttp.protocol_version
+    (** Now defined in [Nethttp] *)
 
-type protocol_attribute =
-  [ `Secure_https
-  ]
+type protocol_attribute = Nethttp.protocol_attribute
+    (** Now defined in [Nethttp] *)
 
-type protocol =
-  [ `Http of (protocol_version * protocol_attribute list)
-  | `Other
-  ]
-  (** The base protocol *)
+type protocol = Nethttp.protocol
+    (** Now defined in [Nethttp] *)
 
 type workaround =
   [ `Work_around_MSIE_Content_type_bug
@@ -265,6 +260,9 @@ object
      * header. Use the method [input_header_field] instead.
      *)
 
+  method cgi_properties : (string * string) list
+    (** All properties *)
+
   method cgi_https              : bool
     (** A well-known extension is the [HTTPS] property. It indicates whether
      * a secure connection is used (SSL/TLS). This method interprets this
@@ -272,6 +270,9 @@ object
      * This method fails if there is a [HTTPS] property with an unknown value.
      *)
 
+  method cgi_request_uri : string
+    (** This is the URI path as passed in the HTTP request, without preprocessing *)
+
   (* Convenience: *)
   method protocol : protocol
 
@@ -385,6 +386,11 @@ object
   method set_output_header_fields : (string * string) list -> unit
     (** Sets the complete repsonse header at once. *)
 
+  method set_status : Nethttp.http_status -> unit
+    (** Sets the response status. This is by definition the same as setting the
+      * [Status] output header field.
+     *)
+
   method send_output_header : unit -> unit
     (** If the output state is [`Start], this method will encode and send
      * the output header to the output channel, and the state will be
@@ -408,6 +414,10 @@ object
     (** Sets the output state. This method should only be called by
      * [cgi_activation] implementations.
      *)
+
+  method log_error : string -> unit
+    (** Outputs a log message to the error log. *)
+
     
 (* Note: Setting the output state to `End causes that the output
  * channel is closed. This is the preferred way of closing the
@@ -506,6 +516,9 @@ object
   method set_output_ch : Netchannels.out_obj_channel -> unit
     (** Sets the output channel to use *)
 
+  method set_error_log : (string -> unit) -> unit
+    (** Sets the error log function ([prerr_endline] by default) *)
+
   method setup_finished : unit -> unit
     (** Finishes the setup. After that, it is no longer possible to change
      * it.
@@ -516,6 +529,15 @@ end
  * History:
  * 
  * $Log: netcgi_env.mli,v $
+ * Revision 1.9  2005/07/25 22:36:40  stolpmann
+ * Merge of nethttpd.
+ * Adding the "overview" section to Nethttpd_types.
+ * Cosmetic fixes.
+ * Release updates.
+ *
+ * Revision 1.8.2.1  2005/04/30 16:31:17  stolpmann
+ * Integration of the new Nethttpd component into Ocamlnet.
+ *
  * Revision 1.8  2004/07/24 18:30:49  stolpmann
  * 	ocamldoc
  *
