@@ -1,4 +1,4 @@
-(* $Id: netcgi_fcgi_10.ml,v 1.2 2004/04/03 19:18:15 gremlin43820 Exp $
+(* $Id: netcgi_fcgi_10.ml,v 1.7 2005/02/03 19:16:53 gremlin43820 Exp $
  * ----------------------------------------------------------------------
  *
  *)
@@ -8,6 +8,8 @@ either, the GNU GPL, or the same license as ocamlnet *)
 
 open Unix
 
+exception FCGI_error of string * exn
+
 (* tuneing paramaters *)
 let bufsize = 100;;
 
@@ -142,10 +144,10 @@ let decode_fcgi_begin_request data off =
 
 let decode_fcgi_param data off =
   let get_data data off nmlen vlen = 
-    ((String.sub data off nmlen), (String.sub data (off + nmlen) vlen))
+    ((String.sub data off nmlen), (String.sub data (off + nmlen) vlen), (off + nmlen + vlen))
   in
-    (* check flags for 4 byte encodeing, or 1 byte encodeing of
-       the length of the datum. This is silly on modern machines. 
+    (* check flags for 4 byte encoding, or 1 byte encoding of
+       the length of the datum. This is silly on modern networks. 
        All this work to save 3 bytes, but there we have it :P *)
     if ((lsr) (Char.code (String.get data off)) 7) = 1 then
       (let nmlen = int_from_byte4 data off in
@@ -189,36 +191,63 @@ let encode_fcgi_end_request req id =
   functions which read or write fcgi structures
 ***************************************************)
 let fcgi_read_header con = (* read the packet header *)
-  let buf = String.create 8 in
-  let read = read con buf 0 8 in
-    decode_fcgi_header buf 0
+  try
+    let buf = String.create 8 in
+    let read = read con buf 0 8 in
+      decode_fcgi_header buf 0
+  with Unix_error (e, f, i) -> 
+    raise (FCGI_error ("fcgi_read_header", Unix_error (e, f, i)))
+	
+let fcgi_drop_padding con len =
+  try
+    if len > 0 then
+      let buf = String.make len 'c' in
+      let read = read con buf 0 len in
+	read
+    else
+      0
+  with Unix_error (e, f, i) -> 
+    raise (FCGI_error ("fcgi_drop_padding", Unix_error (e, f, i)))
 
-let fcgi_read_packet con = (* read one full packet *)
-  let header = fcgi_read_header con in
-  let buf = String.create header.contentlen in
-  let read = read con buf 0 header.contentlen in
-    (header, buf)
+let fcgi_read_packet con = (* read one full packet *)  
+  try
+    let header = fcgi_read_header con in
+    let buf = String.create header.contentlen in
+    let read = read con buf 0 header.contentlen in
+    let pad = fcgi_drop_padding con header.padlen in
+      (header, buf)
+  with Unix_error (e, f, i) -> 
+    raise (FCGI_error ("fcgi_read_packet", Unix_error (e, f, i)))
 
 let fcgi_read_begin_request con =
-  let (header, data) = fcgi_read_packet con in
-    match header with
-	{rtype=fcgi_begin_request;contentlen=0} -> failwith "Protocal Error"
-      | {rtype=fcgi_begin_request;requestid=id;contentlen=8} ->
-	  (id, (decode_fcgi_begin_request data 0))
-      | {rtype=_} -> failwith "Invalid FCGI Structure"
+    let (header, data) = fcgi_read_packet con in
+      match header with
+	  {rtype=fcgi_begin_request;contentlen=0} -> failwith "Protocal Error"
+	| {rtype=fcgi_begin_request;requestid=id;contentlen=8} ->
+	    (id, (decode_fcgi_begin_request data 0))
+	| {rtype=_} -> failwith "Invalid FCGI Structure"
 
 (* each packet contains a param. The last one will have content
    length of 0. keep reading params until there are no more *)
 let fcgi_read_params con =
-  let rec fcgi_read_params con param =
+  let rec fcgi_read_params con params =
     let (header, data) = fcgi_read_packet con in
       match header with
-	  {rtype=v;contentlen=0} when v = fcgi_params -> param
+	  {rtype=v;contentlen=0} when v = fcgi_params -> params
 	| {rtype=v} when v = fcgi_params -> 
-	    fcgi_read_params con ((decode_fcgi_param data 0) :: param)
+	    let rec fcgi_parse_block params data header off =
+	      let (n, pv, n_off) = decode_fcgi_param data off in
+		if n_off < header.contentlen then
+	          fcgi_parse_block ((n, pv) :: params) data header n_off
+		else
+	          (n, pv) :: params
+	    in
+	      fcgi_read_params con (fcgi_parse_block params data header 0)
 	| {rtype=_} -> failwith "Invalid FCGI Structure"
   in
-    fcgi_read_params con []
+    try fcgi_read_params con []
+    with Unix_error (e, f, i) -> 
+      raise (FCGI_error ("fcgi_read_params", Unix_error (e, f, i)))
 
 (* each stream packet contains part of the stream data 
    keep reading them and concatinate them all together until
@@ -233,35 +262,41 @@ let fcgi_read_stream type_t con =
 	    read_stream type_t con (Buffer.add_string data payload;data)
 	| {rtype=_} -> failwith "Invalid FCGI Structure"
   in
-    read_stream type_t con (Buffer.create bufsize)
-
+    try read_stream type_t con (Buffer.create bufsize)
+    with Unix_error (e, f, i) -> 
+      raise (FCGI_error ("fcgi_read_stream", Unix_error (e, f, i)))
+      
 let fcgi_read_stdin con =
-  fcgi_read_stream fcgi_stdin con
+  try fcgi_read_stream fcgi_stdin con
+  with Unix_error (e, f, i) -> 
+    raise (FCGI_error ("fcgi_read_stdin", Unix_error (e, f, i)))
 
 let fcgi_read_data con =
-  fcgi_read_stream fcgi_data con
+  try fcgi_read_stream fcgi_data con
+  with Unix_error (e, f, i) -> 
+    raise (FCGI_error ("fcgi_read_data", Unix_error (e, f, i)))
 
 (* read a full responder request *)
 let fcgi_read_responder_request con id =
-  let params  = fcgi_read_params con in
+  let params = fcgi_read_params con in
   let stdin = fcgi_read_stdin con in 
-     {id=id;
-      app_type=fcgi_responder;
-      params=params;
-      stdin=stdin;
-      data="";
-      con=con}
+    {id=id;
+     app_type=fcgi_responder;
+     params=params;
+     stdin=stdin;
+     data="";
+     con=con}
 
 (* read full authorizer request (note, this is the same as the responder)*)
 let fcgi_read_authorizer_request con id =
   let params  = fcgi_read_params con in
   let stdin = fcgi_read_stdin con in 
-     {id=id;
-      app_type=fcgi_authorizer;
-      params=params;
-      stdin=stdin;
-      data="";
-      con=con}
+    {id=id;
+     app_type=fcgi_authorizer;
+     params=params;
+     stdin=stdin;
+     data="";
+     con=con}
 
 let fcgi_read_filter_request con id =
   let params = fcgi_read_params con in
@@ -284,36 +319,35 @@ let fcgi_read_request con =
       | {role=_}                          -> failwith "FCGI Role Not Supported"
 
 let fcgi_write_end_request req endreq =
-  ignore (write req.con (encode_fcgi_end_request endreq req.id) 0 16)
+  try ignore (write req.con (encode_fcgi_end_request endreq req.id) 0 16)
+  with Unix_error (e, f, i) -> 
+    raise (FCGI_error ("fcgi_write_end_request", Unix_error (e, f, i)))
+
 
 let fcgi_write_stdout req data =
-  ignore (write req.con (encode_fcgi_data data req.id fcgi_stdout) 0 (8 + (String.length data)))
+  try ignore (write req.con (encode_fcgi_data data req.id fcgi_stdout) 0 (8 + (String.length data)))
+  with Unix_error (e, f, i) -> 
+    raise (FCGI_error ("fcgi_write_stdout", Unix_error (e, f, i)))
 
 let fcgi_write_stderr req data = 
-  ignore (write req.con (encode_fcgi_data data req.id fcgi_stderr) 0 (8 + (String.length data)))
-
-(* check that the ip address is correct *)
-let check_addr addr = true
-
-(* veryify that we are talking to fastcgi *)
-let fcgi_verify unit = 
-  try
-    let socaddr = getpeername Unix.stdin in false
-  with Unix_error(ENOTCONN, _, _) -> true
-    | Unix_error(_, _, _) -> false  
+  try ignore (write req.con (encode_fcgi_data data req.id fcgi_stderr) 0 (8 + (String.length data)))
+  with Unix_error (e, f, i) -> 
+    raise (FCGI_error ("fcgi_write_stderr", Unix_error (e, f, i)))
 
 (* accept a conn from fastcgi *)
 let fcgi_accept unit =
   try
     let (con, addr) = accept Unix.stdin in
-      (if (fcgi_verify ()) = false then
-	 failwith "you are not fastcgi");
-      (if (check_addr addr) = false then
-	 failwith "invalid address");
       fcgi_read_request con
-  with Unix_error(e, s, t) -> 
-    prerr_endline (error_message e); 
-    failwith "An Unrecoverable error has occurred";;
+  with exn -> raise (FCGI_error ("fcgi_accept", exn));;
+
+(* for toplevel debugging. In the case of apache mod_fastcgi, use the
+   FastCGIExternalServer directive, open up the socket in the
+   toplevel, and you'll be able to talk fastcgi protocol with the web
+   server inside your toplevel *)
+let fcgi_debug_accept s = 
+  let (con, addr) = accept s in
+    fcgi_read_request con
 
 (* destroy a connection when we're done with it *)
 let fcgi_destroy req = close req.con
@@ -322,11 +356,7 @@ let fcgi_destroy req = close req.con
  * History:
  * 
  * $Log: netcgi_fcgi_10.ml,v $
- * Revision 1.2  2004/04/03 19:18:15  gremlin43820
- * performance improvements for fast cgi core
+ * Revision 1.7  2005/02/03 19:16:53  gremlin43820
+ * open unix in netcgi_fcgi.ml to fix compiler error. Make naming clearer in netcgi_fcgi_10.ml, in read_params, pluralize the list of params "param" is a confusing name for a list.
  *
- * Revision 1.1  2003/10/07 17:39:32  stolpmann
- * 	Imported Eric's patch for fastcgi
- *
- * 
  *)
