@@ -1,4 +1,4 @@
-(* $Id: netcgi_fcgi_10.mli,v 1.2 2004/07/24 18:30:49 stolpmann Exp $
+(* $Id: netcgi_fcgi_10.mli,v 1.3 2005/02/02 19:05:47 gremlin43820 Exp $
  * ----------------------------------------------------------------------
  *
  *)
@@ -17,6 +17,8 @@ either, the GNU GPL, or the same license as ocamlnet *)
    you really like your, your helpdesk operators :P 
 *)
 
+exception FCGI_error of string * exn
+
 (* protocal header *)
 type fcgiHeader = {version: int; rtype: int; requestid: int; contentlen: int; padlen: int}
 
@@ -57,6 +59,9 @@ val fcgi_write_end_request: fcgiRequest -> fcgiEndRequestBody -> unit
  * History:
  * 
  * $Log: netcgi_fcgi_10.mli,v $
+ * Revision 1.3  2005/02/02 19:05:47  gremlin43820
+ * added the exception to the interface file
+ *
  * Revision 1.2  2004/07/24 18:30:49  stolpmann
  * 	ocamldoc
  *
