@@ -1,4 +1,4 @@
-(* $Id: netcgi_jserv.ml,v 1.6 2004/05/30 21:27:14 stolpmann Exp $
+(* $Id: netcgi_jserv.ml,v 1.7 2005/04/14 20:13:05 stolpmann Exp $
  * ----------------------------------------------------------------------
  *
  *)
@@ -63,7 +63,7 @@ let signal_restart srv =
       Some p ->
 	if srv.closed then raise Server_is_down;
 	( try
-	    let _ = restart (U.write p "R" 0) 1 in
+	    let _ = restart (U.single_write p "R" 0) 1 in
 	    ()
 	  with
 	      U.Unix_error(U.EPIPE,_,_) -> raise Server_is_down
@@ -78,7 +78,7 @@ let signal_shutdown srv =
       Some p ->
 	if srv.closed then raise Server_is_down;
 	( try
-	    let _ = restart (U.write p "S" 0) 1 in
+	    let _ = restart (U.single_write p "S" 0) 1 in
 	    ()
 	  with
 	      U.Unix_error(U.EPIPE,_,_) -> raise Server_is_down
@@ -429,6 +429,9 @@ let jvm_emu_main est_server =
  * History:
  * 
  * $Log: netcgi_jserv.ml,v $
+ * Revision 1.7  2005/04/14 20:13:05  stolpmann
+ * Using Unix.single_write instead of Unix.write.
+ *
  * Revision 1.6  2004/05/30 21:27:14  stolpmann
  * 	Supporting the standard for class-based I/O. This also means
  * the semantics of [input] and [output] methods have changed (return
