@@ -1,8 +1,10 @@
-(* $Id: netcgi_types.ml,v 1.7 2004/07/01 12:56:20 stolpmann Exp $
+(* $Id: netcgi_types.ml,v 1.8 2005/07/25 22:36:40 stolpmann Exp $
  * ----------------------------------------------------------------------
  *
  *)
 
+open Nethttp
+
 exception Resources_exceeded
 
 class type simple_message = Netmime.mime_body
@@ -37,7 +39,7 @@ object
 end
 
 
-type cgi_cookie = (* Cgi.cookie = *)
+type cgi_cookie = Nethttp.cookie =
     { cookie_name : string;
       cookie_value : string;
       cookie_expires : float option;
@@ -47,51 +49,7 @@ type cgi_cookie = (* Cgi.cookie = *)
     }
 
 
-type status = 
-  (* 2xx: (successful) *)
-  [ `Ok
-  | `Created
-  | `Accepted
-  | `Non_authoritative
-  | `No_content
-  | `Reset_content
-  | `Partial_content
-  (* 3xx: (redirection) *)
-  | `Multiple_choices
-  | `Moved_permanently
-  | `Found
-  | `See_other
-  | `Not_modified
-  | `Use_proxy
-  | `Temporary_redirect
-  (* 4xx: (client error) *)
-  | `Bad_request
-  | `Unauthorized
-  | `Payment_required
-  | `Forbidden
-  | `Not_found
-  | `Method_not_allowed
-  | `Not_acceptable
-  | `Proxy_auth_required
-  | `Request_timeout
-  | `Conflict
-  | `Gone
-  | `Length_required
-  | `Precondition_failed
-  | `Request_entity_too_large
-  | `Request_uri_too_long
-  | `Unsupported_media_type
-  | `Requested_range_not_satisfiable
-  | `Expectation_failed
-  (* 5xx: (server error) *)
-  | `Internal_server_error
-  | `Not_implemented
-  | `Bad_gateway
-  | `Service_unavailable
-  | `Gateway_timeout
-  | `Http_version_not_supported 
-  ]
-
+type status = http_status
 
 type request_method =
   [ `GET
@@ -169,6 +127,15 @@ end
  * History:
  * 
  * $Log: netcgi_types.ml,v $
+ * Revision 1.8  2005/07/25 22:36:40  stolpmann
+ * Merge of nethttpd.
+ * Adding the "overview" section to Nethttpd_types.
+ * Cosmetic fixes.
+ * Release updates.
+ *
+ * Revision 1.7.2.1  2005/04/30 16:31:17  stolpmann
+ * Integration of the new Nethttpd component into Ocamlnet.
+ *
  * Revision 1.7  2004/07/01 12:56:20  stolpmann
  * 	Removed dependency on Cgi.
  *
