@@ -1,4 +1,4 @@
-(* $Id: netcgi_types.mli,v 1.11 2004/07/23 21:19:32 stolpmann Exp $
+(* $Id: netcgi_types.mli,v 1.12 2005/07/25 22:36:40 stolpmann Exp $
  * ----------------------------------------------------------------------
  *
  *)
@@ -134,7 +134,7 @@ object
 end
 
 
-type cgi_cookie = (* Cgi.cookie =  *)
+type cgi_cookie = Nethttp.cookie =
     { cookie_name : string;
         (** The name of the cookie *)
       cookie_value : string;
@@ -170,101 +170,7 @@ type cgi_cookie = (* Cgi.cookie =  *)
     }
 
 
-type status =   (* Status codes from RFC 2616 *)
-  (* 2xx: (successful) *)
-  [ `Ok
-  | `Created
-  | `Accepted
-  | `Non_authoritative
-  | `No_content
-  | `Reset_content
-  | `Partial_content
-  (* 3xx: (redirection) *)
-  | `Multiple_choices
-  | `Moved_permanently
-  | `Found
-  | `See_other
-  | `Not_modified
-  | `Use_proxy
-  | `Temporary_redirect
-  (* 4xx: (client error) *)
-  | `Bad_request
-  | `Unauthorized
-  | `Payment_required
-  | `Forbidden
-  | `Not_found
-  | `Method_not_allowed
-  | `Not_acceptable
-  | `Proxy_auth_required
-  | `Request_timeout
-  | `Conflict
-  | `Gone
-  | `Length_required
-  | `Precondition_failed
-  | `Request_entity_too_large
-  | `Request_uri_too_long
-  | `Unsupported_media_type
-  | `Requested_range_not_satisfiable
-  | `Expectation_failed
-  (* 5xx: (server error) *)
-  | `Internal_server_error
-  | `Not_implemented
-  | `Bad_gateway
-  | `Service_unavailable
-  | `Gateway_timeout
-  | `Http_version_not_supported 
-  ]
-  (** HTTP response status:
-   * 
-   * {b Successful (2xx):}
-   * - [`Ok]
-   * - [`Created]
-   * - [`Accepted]
-   * - [`Non_authoritative]
-   * - [`No_content]
-   * - [`Reset_content]
-   * - [`Partial_content]
-   *
-   * {b Redirection (3xx):}
-   * - [`Multiple_choices]
-   * - [`Moved_permanently]
-   * - [`Found]
-   * - [`See_other]
-   * - [`Not_modified]
-   * - [`Use_proxy]
-   * - [`Temporary_redirect]
-   * 
-   * {b Client error (4xx):}
-   * - [`Bad_request]
-   * - [`Unauthorized]
-   * - [`Payment_required]
-   * - [`Forbidden]
-   * - [`Not_found]
-   * - [`Method_not_allowed]
-   * - [`Not_acceptable]
-   * - [`Proxy_auth_required]
-   * - [`Request_timeout]
-   * - [`Conflict]
-   * - [`Gone]
-   * - [`Length_required]
-   * - [`Precondition_failed]
-   * - [`Request_entity_too_large]
-   * - [`Request_uri_too_long]
-   * - [`Unsupported_media_type]
-   * - [`Request_range_not_satisfiable]
-   * - [`Expectation_failed]
-   *
-   * {b Server Error (5xx):}
-   * - [`Internal_server_error]
-   * - [`Not_implemented]
-   * - [`Bad_gateway]
-   * - [`Service_unavailable]
-   * - [`Gateway_timeout]
-   * - [`Http_version_not_supported]
-   *)
-
-  (* The type "status" may be moved to another, HTTP-specific module *)
-
+type status = Nethttp.http_status
 
 type request_method =
   [ `GET
@@ -627,6 +533,15 @@ end
  * History:
  * 
  * $Log: netcgi_types.mli,v $
+ * Revision 1.12  2005/07/25 22:36:40  stolpmann
+ * Merge of nethttpd.
+ * Adding the "overview" section to Nethttpd_types.
+ * Cosmetic fixes.
+ * Release updates.
+ *
+ * Revision 1.11.2.1  2005/04/30 16:31:17  stolpmann
+ * Integration of the new Nethttpd component into Ocamlnet.
+ *
  * Revision 1.11  2004/07/23 21:19:32  stolpmann
  * 	Added ocamldoc
  *
