@@ -1,4 +1,4 @@
-(* $Id: netbuffer.ml,v 2.3 2002/03/15 15:19:08 stolpmann Exp $
+(* $Id: netbuffer.ml,v 2.4 2004/07/06 17:52:34 stolpmann Exp $
  * ----------------------------------------------------------------------
  *
  *)
@@ -52,12 +52,12 @@ let contents b =
   String.sub b.buffer 0 b.length
     
 let sub b k n =
-  if k+n > b.length then
+  if k < 0 || n < 0 || k+n > b.length then
     raise (Invalid_argument "Netbuffer.sub");
   String.sub b.buffer k n
 
 let blit b srcpos dest destpos n =
-  if srcpos+n > b.length then
+  if srcpos < 0 || n < 0 || srcpos+n > b.length then
     raise (Invalid_argument "Netbuffer.blit");
   String.blit b.buffer srcpos dest destpos n
     
@@ -81,14 +81,24 @@ let ensure_space b n =
     b.buffer <- buffer'
   end
 
-let add_sub_string b s k l =
+let add_sub_string_int b s k l =
   ensure_space b (l + b.length);
   String.blit s k b.buffer b.length l;
   b.length <- b.length + l
 
+let add_sub_string b s k l =
+  if k < 0 || l < 0 || k+l > String.length s then
+    invalid_arg "Netbuffer.add_sub_string";
+  add_sub_string_int b s k l
+
 let add_string b s =
   add_sub_string b s 0 (String.length s)
 
+let add_char b c =
+  ensure_space b (b.length+1);
+  b.buffer.[b.length] <- c;
+  b.length <- b.length + 1
+
 let add_inplace ?len b f =
   let len' =
     match len with
@@ -102,7 +112,32 @@ let add_inplace ?len b f =
   let n = f b.buffer b.length len' in
   b.length <- b.length + n;
   n
-    
+
+let insert_sub_string_int b p s k l =
+  if p < 0 || p > b.length then
+    invalid_arg "Netbuffer.insert_sub_string";
+  ensure_space b (l + b.length);
+  String.blit b.buffer p b.buffer (p+l) (b.length - p);
+  String.blit s k b.buffer p l;
+  b.length <- b.length + l
+
+let insert_sub_string b p s k l =
+  if k < 0 || l < 0 || k+l > String.length s then
+    invalid_arg "Netbuffer.insert_sub_string";
+  insert_sub_string_int b p s k l
+
+let insert_string b p s =
+  insert_sub_string_int b p s 0 (String.length s)
+
+let insert_char b p c =
+  if p < 0 || p > b.length then
+    invalid_arg "Netbuffer.insert_char";
+  ensure_space b (1 + b.length);
+  String.blit b.buffer p b.buffer (p+1) (b.length - p);
+  b.buffer.[p] <- c;
+  b.length <- b.length + 1
+
+
 let delete b k l =
   (* deletes l bytes at position k in b *)
   let n = String.length b.buffer in
@@ -143,6 +178,9 @@ let print_buffer b =
  * History:
  * 
  * $Log: netbuffer.ml,v $
+ * Revision 2.4  2004/07/06 17:52:34  stolpmann
+ * 	New: add_char, insert_string, insert_sub_string, insert_char
+ *
  * Revision 2.3  2002/03/15 15:19:08  stolpmann
  * 	Fix: Large buffers with a length near Sys.max_string_length
  * are supported.
