@@ -1,4 +1,4 @@
-(* $Id: netchannels.ml,v 1.18 2004/07/11 15:40:29 stolpmann Exp $
+(* $Id: netchannels.ml,v 1.19 2005/04/14 20:13:19 stolpmann Exp $
  * ----------------------------------------------------------------------
  *
  *)
@@ -1279,7 +1279,7 @@ object (self)
   method output buf pos len =
     if closed_out then self # complain_closed();
     try
-      let n = Unix.write fd_out buf pos len in
+      let n = Unix.single_write fd_out buf pos len in
       pos_out <- pos_out + n;
       n
     with
@@ -1735,6 +1735,9 @@ end
  * History:
  * 
  * $Log: netchannels.ml,v $
+ * Revision 1.19  2005/04/14 20:13:19  stolpmann
+ * Using Unix.single_write instead of Unix.write.
+ *
  * Revision 1.18  2004/07/11 15:40:29  stolpmann
  * 	Added: enhanced_input
  *
