@@ -18,7 +18,6 @@ type token =
   | Colon
   | Slash
   | Invalid
-;;
 
 let tokens_list =
   ["january", Month 1; "jan", Month 1; "february", Month 2; "feb", Month 2;
@@ -47,7 +46,6 @@ let tokens_list =
    "cst", Zone (-0600); "cdt", Zone (-0500); "est", Zone (-0500);
    "edt", Zone (-0400); "ast", Zone (-0400); "adt", Zone (-0300);
    "wat", Zone (-0100); "at", Zone (-0200)]
-;;
 
 let find_token =
   let tokens = Hashtbl.create 53 in
@@ -56,7 +54,6 @@ let find_token =
   fun name ->
     try Hashtbl.find tokens name with
       Not_found -> Invalid
-;;
 
 let tokens_of_string str =
   let rec scan_any (strm__ : _ Stream.t) =
@@ -124,7 +121,6 @@ let tokens_of_string str =
     | _ -> raise Stream.Failure
   in
   scan_any (Stream.of_string str)
-;;
 
 type t =
   { year : int;
@@ -135,7 +131,6 @@ type t =
     second : int;
     zone : int;
     week_day : int }
-;;
 
 let parse str =
   let tokens = tokens_of_string str in
@@ -147,49 +142,60 @@ let parse str =
   and day = ref None
   and month = ref None
   and year = ref None in
-  let add_data ?h ?m ?s ?mdn ?tz ?dst ?wd ?md ?mo ?y () =
-    let may_store r =
-      function
-        None -> ()
-      | v when !r = None -> r := v
-      | _ -> invalid_arg "Parse.date"
-    in
-    let tz =
-      match tz, dst with
-        Some tz, Some true -> Some (tz - 100)
-      | _ -> tz
-    in
-    let tz =
-      match tz with
-        None -> None
-      | Some x -> Some (x mod 100 + 60 * (x / 100))
-    in
-    let h =
-      match h with
-        None -> None
-      | Some h ->
-          match mdn with
-            None when h >= 0 && h <= 23 -> Some h
-          | Some false when h > 0 && h <= 11 -> Some h
-          | Some false when h = 12 -> Some 0
-          | Some true when h > 0 && h <= 11 -> Some (h + 12)
-          | Some true when h = 12 -> Some 12
-    in
-    let y =
-      match y with
-        None -> None
-      | Some y when y >= 100 -> Some y
-      | Some y when y < 69 -> Some (2000 + y)
-      | Some y -> Some (1900 + y)
-    in
-    may_store hour h;
-    may_store minute m;
-    may_store second s;
-    may_store zone tz;
-    may_store week_day wd;
-    may_store day md;
-    may_store month mo;
-    may_store year y
+  let add_data =
+    fun ?h ->
+      fun ?m ->
+        fun ?s ->
+          fun ?mdn ->
+            fun ?tz ->
+              fun ?dst ->
+                fun ?wd ->
+                  fun ?md ->
+                    fun ?mo ->
+                      fun ?y () ->
+                        let may_store r =
+                          function
+                            None -> ()
+                          | v when !r = None -> r := v
+                          | _ -> invalid_arg "Parse.date"
+                        in
+                        let tz =
+                          match tz, dst with
+                            Some tz, Some true -> Some (tz - 100)
+                          | _ -> tz
+                        in
+                        let tz =
+                          match tz with
+                            None -> None
+                          | Some x -> Some (x mod 100 + 60 * (x / 100))
+                        in
+                        let h =
+                          match h with
+                            None -> None
+                          | Some h ->
+                              match mdn with
+                                None when h >= 0 && h <= 23 -> Some h
+                              | Some false when h > 0 && h <= 11 -> Some h
+                              | Some false when h = 12 -> Some 0
+                              | Some true when h > 0 && h <= 11 ->
+                                  Some (h + 12)
+                              | Some true when h = 12 -> Some 12
+                        in
+                        let y =
+                          match y with
+                            None -> None
+                          | Some y when y >= 100 -> Some y
+                          | Some y when y < 69 -> Some (2000 + y)
+                          | Some y -> Some (1900 + y)
+                        in
+                        may_store hour h;
+                        may_store minute m;
+                        may_store second s;
+                        may_store zone tz;
+                        may_store week_day wd;
+                        may_store day md;
+                        may_store month mo;
+                        may_store year y
   in
   let rec scan_gen (strm__ : _ Stream.t) =
     match Stream.peek strm__ with
@@ -365,13 +371,10 @@ let parse str =
    hour = get_default 0 hour; minute = get_default 0 minute;
    second = get_default 0 second; zone = get_default 0 zone;
    week_day = get_default (-1) week_day}
-;;
 
-let months_start =
-  [| 0; 31; 59; 90; 120; 151; 181; 212; 243; 273; 304; 334 |]
-;;
+let months_start = [| 0; 31; 59; 90; 120; 151; 181; 212; 243; 273; 304; 334 |]
 
-let is_leap year = year mod 4 = 0 && (year mod 100 <> 0 || year mod 400 = 0);;
+let is_leap year = year mod 4 = 0 && (year mod 100 <> 0 || year mod 400 = 0)
 
 let since_epoch date =
   if date.month < 1 || date.month > 12 then invalid_arg "Parse.since_epoch";
@@ -386,9 +389,8 @@ let since_epoch date =
   let days = days + months_start.(date.month - 1) + date.day - 1 in
   let days = if is_leap date.year && date.month > 2 then days + 1 else days in
   86400.0 *. float_of_int days +. in_day
-;;
 
-let parse_epoch str = since_epoch (parse str);;
+let parse_epoch str = since_epoch (parse str)
 
 let create ?(zone = 0) time =
   let time = time +. float_of_int (zone * 60) in
@@ -429,24 +431,20 @@ let create ?(zone = 0) time =
   {year = year; month = month + 1; day = r1 - month_start month + 1;
    hour = hour; minute = minute; second = second; zone = zone;
    week_day = int_of_float (mod_float (days +. 6.0) 7.0)}
-;;
 
 let full_day_names =
   [| "Sunday"; "Monday"; "Tuesday"; "Wednesday"; "Thursday"; "Friday";
      "Saturday" |]
-;;
 
-let abbr_day_names = [| "Sun"; "Mon"; "Tue"; "Wed"; "Thu"; "Fri"; "Sat" |];;
+let abbr_day_names = [| "Sun"; "Mon"; "Tue"; "Wed"; "Thu"; "Fri"; "Sat" |]
 
 let full_month_names =
   [| "January"; "February"; "March"; "April"; "May"; "June"; "Jully";
      "August"; "September"; "October"; "November"; "December" |]
-;;
 
 let abbr_month_names =
   [| "Jan"; "Feb"; "Mar"; "Apr"; "May"; "Jun"; "Jul"; "Aug"; "Sep"; "Oct";
      "Nov"; "Dec" |]
-;;
 
 let format_to out_ch ~fmt date =
   let add_char c = out_ch#output_char c
@@ -556,12 +554,10 @@ let format_to out_ch ~fmt date =
   in
   try aux 0 with
     _ -> fail ()
-;;
 
 let format ~fmt date =
   let b = Buffer.create (String.length fmt * 2) in
   format_to (new Netchannels.output_buffer b) ~fmt date; Buffer.contents b
-;;
 
 (* Calculate local zone offset in minutes *)
 let localzone =
@@ -576,7 +572,6 @@ let localzone =
   if day_diff < -1 || day_diff = 1 then min_diff + 24 * 60
   else if day_diff > 1 || day_diff = -1 then min_diff - 24 * 60
   else min_diff
-;;
 
 
 (* The format routines above may want to support internationalization
@@ -584,13 +579,11 @@ let localzone =
  * described in the relevant RFCs.
  *)
 
-let mk_mail_date ?zone t =
-  format "%a, %d %b %Y %H:%M:%S %z" (create ?zone t)
-;;
+let mk_mail_date =
+  fun ?zone t -> format "%a, %d %b %Y %H:%M:%S %z" (create ?zone t)
 
-let mk_usenet_date ?zone t =
-  format "%A, %d-%b-%y %H:%M:%S %z" (create ?zone t)
-;;
+let mk_usenet_date =
+  fun ?zone t -> format "%A, %d-%b-%y %H:%M:%S %z" (create ?zone t)
 
 
 (* ======================================================================
