@@ -1,4 +1,4 @@
-(* $Id: netencoding.ml,v 2.16 2005/04/14 12:44:40 stolpmann Exp $
+(* $Id: netencoding.ml,v 2.17 2005/06/27 14:21:30 stolpmann Exp $
  * ----------------------------------------------------------------------
  *
  *)
@@ -1547,13 +1547,21 @@ module Html = struct
 	 (* TODO: avoid String.sub *)
 	 let occurence = occurences.(k) in
 	 let replacement =
-	   let num = Pcre.get_substring occurence 2 in   (* or "" *)
+	   let num = 
+	     try Pcre.get_substring occurence 2 with Not_found -> "" in
+	   (* Note: Older versions of Pcre return "" when the substring
+	    * did not match, newer versions raise Not_found  
+	    *)
 	   if num <> "" then begin
 	     let n = int_of_string num in
 	     makechar n
 	   end
 	   else begin
-	     let name = Pcre.get_substring occurence 3 in  (* or "" *)
+	     let name = 
+	       try Pcre.get_substring occurence 3 with Not_found -> "" in
+	     (* Note: Older versions of Pcre return "" when the substring
+	      * did not match, newer versions raise Not_found  
+	      *)
 	     assert(name <> "");
 	     lookup_entity name
 	   end
@@ -1584,6 +1592,10 @@ end
  * History:
  * 
  * $Log: netencoding.ml,v $
+ * Revision 2.17  2005/06/27 14:21:30  stolpmann
+ * Pcre: Newer versions of this library raise Not_found instead of
+ * returning "" when get_substring does not have a matching string.
+ *
  * Revision 2.16  2005/04/14 12:44:40  stolpmann
  * One can now select LF as line terminator for all message writing
  * functions. Netsendmail.sendmail defaults to LF for Unix compatiblity.
