@@ -1,4 +1,4 @@
-(* $Id: netmime.ml,v 1.10 2005/04/14 12:44:40 stolpmann Exp $
+(* $Id: netmime.ml,v 1.12 2005/07/25 22:36:41 stolpmann Exp $
  * ----------------------------------------------------------------------
  *
  *)
@@ -133,10 +133,10 @@ end = struct
     match l.first with
 	Some c ->
 	  f c;
-	  let cur = ref c in
-	  while !cur.next <> None do
-	    cur := next !cur;
-	    f !cur
+	  let current = ref c in
+	  while (let c0 = ! current in c0.next) <> None do  (* Error in camlp4 *)
+	    current := next !current;
+	    f !current
 	  done; ()
       | None ->
 	  ()
@@ -785,7 +785,7 @@ let rec write_mime_message_int ?(wr_header = true) ?(wr_body = true) ?(nr = 0)
 	    (fun part ->
 	       outch # output_string boundary_string;
 	       write_mime_message_int 
-	         ~wr_header:true ~wr_body:true ~nr:(nr + 1) outch part;
+	         ~wr_header:true ~wr_body:true ~nr:(nr + 1) ~crlf outch part;
 	       outch # output_string eol;
 	    )
 	    parts;
@@ -809,6 +809,19 @@ let write_mime_message ?wr_header ?wr_body ?nr ?ret_boundary ?crlf ch msg =
  * History:
  * 
  * $Log: netmime.ml,v $
+ * Revision 1.12  2005/07/25 22:36:41  stolpmann
+ * Merge of nethttpd.
+ * Adding the "overview" section to Nethttpd_types.
+ * Cosmetic fixes.
+ * Release updates.
+ *
+ * Revision 1.11  2005/06/27 13:55:36  stolpmann
+ * Fix write_mime_message: The argument [crlf] is passed down to recursive
+ * activations of the function.
+ *
+ * Revision 1.10.2.1  2005/04/30 16:31:18  stolpmann
+ * Integration of the new Nethttpd component into Ocamlnet.
+ *
  * Revision 1.10  2005/04/14 12:44:40  stolpmann
  * One can now select LF as line terminator for all message writing
  * functions. Netsendmail.sendmail defaults to LF for Unix compatiblity.
