@@ -1,4 +1,4 @@
-(* $Id: netsendmail.mli,v 1.4 2004/07/04 18:49:53 stolpmann Exp $
+(* $Id: netsendmail.mli,v 1.5 2005/04/14 12:44:40 stolpmann Exp $
  * ----------------------------------------------------------------------
  *
  *)
@@ -325,13 +325,17 @@ val format_field_value : string -> Mimestring.s_token list -> string
 
 (** {1:sending Sending Messages} *)
 
-val sendmail : ?mailer:string -> Netmime.complex_mime_message -> unit
+val sendmail : ?mailer:string -> ?crlf:bool -> Netmime.complex_mime_message -> unit
   (** Sends the passed message. The mailer program must be sendmail-compatible
    * (this can be assumed on all Unix systems, even if a non-sendmail
    * mailer is installed).
    *
    * The mailer program is the command passed as [mailer], which is by
    * default a reasonable compile-time setting.
+   *
+   * With [crlf] one can determine the EOL convention for the message piped to
+   * the mailer program: If [crlf], CR/LF is used, if [not crlf], only LF is
+   * used. The default is [false] for Unix systems.
    *)
 
 
@@ -550,6 +554,10 @@ val sendmail : ?mailer:string -> Netmime.complex_mime_message -> unit
  * History:
  * 
  * $Log: netsendmail.mli,v $
+ * Revision 1.5  2005/04/14 12:44:40  stolpmann
+ * One can now select LF as line terminator for all message writing
+ * functions. Netsendmail.sendmail defaults to LF for Unix compatiblity.
+ *
  * Revision 1.4  2004/07/04 18:49:53  stolpmann
  * 	Revised interface: Mails can also be composed with
  * wrap_mail, wrap_parts, and wrap_attachment, in addition to the
