@@ -1,4 +1,4 @@
-(* $Id: neturl.ml,v 2.3 2004/07/18 16:36:24 stolpmann Exp $
+(* $Id: neturl.ml,v 2.4 2005/01/26 11:51:40 stolpmann Exp $
  * ----------------------------------------------------------------------
  *
  *)
@@ -604,19 +604,19 @@ let modify_url
   =
 
   let encode = Netencoding.Url.encode ~plus:true in
-  let enc x =
+  let enc ?(plus=false) x =
     if encoded then
       x
     else
       match x with
 	  None -> None
-	| Some x' -> Some (encode x')
+	| Some x' -> Some (Netencoding.Url.encode ~plus x')
   in
-  let enc_list l = 
+  let enc_list ?(plus=false) l = 
     if encoded then
       l
     else
-      List.map encode l 
+      List.map (Netencoding.Url.encode ~plus) l 
   in
 
   let new_syntax =
@@ -667,7 +667,7 @@ let modify_url
       url_param    = (match param with
 			  None -> url.url_param
 			| Some p -> enc_list p);
-      url_query    = if query    = None then url.url_query    else enc query;
+      url_query    = if query    = None then url.url_query    else enc ~plus:true query;
       url_fragment = if fragment = None then url.url_fragment else enc fragment;
       url_other    = if other    = None then url.url_other    else enc other;
     }
@@ -969,20 +969,20 @@ let return_if value =
 ;;
 
 
-let decode_if want_encoded value =
+let decode_if ?(plus=false) want_encoded value =
   let value' = return_if value in
   if want_encoded then
     value'
   else
-    Netencoding.Url.decode value'
+    Netencoding.Url.decode ~plus value'
 ;;
 
 
-let decode_path_if want_encoded value =
+let decode_path_if ?(plus=false) want_encoded value =
   if want_encoded then
     value
   else
-    List.map (Netencoding.Url.decode ~plus:true) value 
+    List.map (Netencoding.Url.decode ~plus) value 
 ;;
 
 
@@ -994,7 +994,7 @@ let url_host                        url = return_if url.url_host;;
 let url_port                        url = return_if url.url_port;;
 let url_path       ?(encoded=false) url = decode_path_if encoded url.url_path;;
 let url_param      ?(encoded=false) url = decode_path_if encoded url.url_param;;
-let url_query      ?(encoded=false) url = decode_if encoded url.url_query;;
+let url_query      ?(encoded=false) url = decode_if ~plus:true encoded url.url_query;;
 let url_fragment   ?(encoded=false) url = decode_if encoded url.url_fragment;;
 let url_other      ?(encoded=false) url = decode_if encoded url.url_other;;
 
@@ -1700,6 +1700,11 @@ let local_path_of_file_url u =
  * History:
  * 
  * $Log: neturl.ml,v $
+ * Revision 2.4  2005/01/26 11:51:40  stolpmann
+ * 	Fix: Encoding of spaces in URLs. In previous versions, the plus
+ * sign was handled as equal to %20 everywhere in the URL. This is wrong.
+ * The plus sign has only a special meaning in the query part of the URL.
+ *
  * Revision 2.3  2004/07/18 16:36:24  stolpmann
  * 	New: Neturl.file_url_of_local_path, local_path_of_file_url.
  * 	URL updates according to RFC 2396.
